#include <zephyr.h>
#include <drivers/spi.h>
#include <drivers/gpio.h>
#include <logging/log.h>

LOG_MODULE_REGISTER(main, LOG_LEVEL_INF);

#define GPIO_DRV_PORT	DT_NORDIC_NRF_GPIO_GPIO_0_LABEL
#define CSN_PIN         DT_GPIO_LEDS_LED_0_GPIOS_PIN
#define SPI_DRV_NAME    DT_NORDIC_NRF_SPI_SPI_1_LABEL

#define BUF_SIZE 12

u8_t buffer_tx[BUF_SIZE] = "Hello World";
u8_t buffer_rx[BUF_SIZE];

struct device *spi_dev;
struct device *gpio_dev;

struct spi_cs_control cs_cfg = {
        .gpio_dev = NULL,
	.gpio_pin = CSN_PIN,
	.delay = 100,
};

const struct spi_config spi_cfg_slow = {
	.frequency = 1000000,
	.operation = SPI_OP_MODE_MASTER |  SPI_WORD_SET(8) | SPI_LINES_SINGLE,
	.slave = 0,
	.cs = &cs_cfg,
};

const struct spi_buf tx_bufs[] = {
        {
                .buf = buffer_tx,
                .len = BUF_SIZE,
        },
};
const struct spi_buf rx_bufs[] = {
        {
                .buf = buffer_rx,
                .len = BUF_SIZE,
        },
};
const struct spi_buf_set tx = {
        .buffers = tx_bufs,
        .count = ARRAY_SIZE(tx_bufs)
};
const struct spi_buf_set rx = {
        .buffers = rx_bufs,
        .count = ARRAY_SIZE(rx_bufs)
};

void main(void)
{
	int ret;

      	gpio_dev = device_get_binding(GPIO_DRV_PORT);
        if (!gpio_dev) {
                LOG_INF("gpio port was not found %s!\n", GPIO_DRV_PORT);     
                return;
	}
        LOG_INF("gpio port initialized");  


        spi_dev = device_get_binding(SPI_DRV_NAME);
	if (!spi_dev) {
		LOG_ERR("spi was not found %s!\n", SPI_DRV_NAME);		
		return;
	}
        LOG_INF("spi initialized");  

        cs_cfg.gpio_dev = gpio_dev;

        while(1)
        {
                //gpio_pin_configure(gpio_dev, CSN_PIN,0);
                //gpio_pin_write(gpio_dev, CSN_PIN, 0);
                ret = spi_transceive(spi_dev, &spi_cfg_slow, &tx, &rx);
                //gpio_pin_write(gpio_dev, CSN_PIN, 1);
                LOG_HEXDUMP_INF(&rx, sizeof(rx), "received");
                k_sleep(1000);
        }
}
